Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type BrokerTemplateInstanceExpansion
- type BrokerTemplateInstanceInterface
- type BrokerTemplateInstancesGetter
- type TemplateClient
- func (c *TemplateClient) BrokerTemplateInstances() BrokerTemplateInstanceInterface
- func (c *TemplateClient) RESTClient() rest.Interface
- func (c *TemplateClient) TemplateInstances(namespace string) TemplateInstanceInterface
- func (c *TemplateClient) Templates(namespace string) TemplateResourceInterface
- type TemplateInstanceExpansion
- type TemplateInstanceInterface
- type TemplateInstancesGetter
- type TemplateInterface
- type TemplateResourceExpansion
- type TemplateResourceInterface
- type TemplatesGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BrokerTemplateInstanceExpansion ¶
type BrokerTemplateInstanceExpansion interface{}
type BrokerTemplateInstanceInterface ¶
type BrokerTemplateInstanceInterface interface {
Create(*template.BrokerTemplateInstance) (*template.BrokerTemplateInstance, error)
Update(*template.BrokerTemplateInstance) (*template.BrokerTemplateInstance, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*template.BrokerTemplateInstance, error)
List(opts v1.ListOptions) (*template.BrokerTemplateInstanceList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *template.BrokerTemplateInstance, err error)
BrokerTemplateInstanceExpansion
}
BrokerTemplateInstanceInterface has methods to work with BrokerTemplateInstance resources.
type BrokerTemplateInstancesGetter ¶
type BrokerTemplateInstancesGetter interface {
BrokerTemplateInstances() BrokerTemplateInstanceInterface
}
BrokerTemplateInstancesGetter has a method to return a BrokerTemplateInstanceInterface. A group's client should implement this interface.
type TemplateClient ¶
type TemplateClient struct {
// contains filtered or unexported fields
}
TemplateClient is used to interact with features provided by the template.openshift.io group.
func New ¶
func New(c rest.Interface) *TemplateClient
New creates a new TemplateClient for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*TemplateClient, error)
NewForConfig creates a new TemplateClient for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *TemplateClient
NewForConfigOrDie creates a new TemplateClient for the given config and panics if there is an error in the config.
func (*TemplateClient) BrokerTemplateInstances ¶
func (c *TemplateClient) BrokerTemplateInstances() BrokerTemplateInstanceInterface
func (*TemplateClient) RESTClient ¶
func (c *TemplateClient) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*TemplateClient) TemplateInstances ¶
func (c *TemplateClient) TemplateInstances(namespace string) TemplateInstanceInterface
func (*TemplateClient) Templates ¶
func (c *TemplateClient) Templates(namespace string) TemplateResourceInterface
type TemplateInstanceExpansion ¶
type TemplateInstanceExpansion interface{}
type TemplateInstanceInterface ¶
type TemplateInstanceInterface interface {
Create(*template.TemplateInstance) (*template.TemplateInstance, error)
Update(*template.TemplateInstance) (*template.TemplateInstance, error)
UpdateStatus(*template.TemplateInstance) (*template.TemplateInstance, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*template.TemplateInstance, error)
List(opts v1.ListOptions) (*template.TemplateInstanceList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *template.TemplateInstance, err error)
TemplateInstanceExpansion
}
TemplateInstanceInterface has methods to work with TemplateInstance resources.
type TemplateInstancesGetter ¶
type TemplateInstancesGetter interface {
TemplateInstances(namespace string) TemplateInstanceInterface
}
TemplateInstancesGetter has a method to return a TemplateInstanceInterface. A group's client should implement this interface.
type TemplateInterface ¶
type TemplateInterface interface {
RESTClient() rest.Interface
BrokerTemplateInstancesGetter
TemplatesGetter
TemplateInstancesGetter
}
type TemplateResourceExpansion ¶
type TemplateResourceExpansion interface{}
type TemplateResourceInterface ¶
type TemplateResourceInterface interface {
Create(*template.Template) (*template.Template, error)
Update(*template.Template) (*template.Template, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*template.Template, error)
List(opts v1.ListOptions) (*template.TemplateList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *template.Template, err error)
TemplateResourceExpansion
}
TemplateResourceInterface has methods to work with TemplateResource resources.
type TemplatesGetter ¶
type TemplatesGetter interface {
Templates(namespace string) TemplateResourceInterface
}
TemplatesGetter has a method to return a TemplateResourceInterface. A group's client should implement this interface.